
function i_err=esperimento_sub(n,f,a,b)

% Oggetto: 
% errore interpolazione f in punti di Chebyshev (scalati in [a,b]).
%
% Dati di ingresso:
% n: numero naturale (grado di interpolazione).
% f: funzione da interpolare in [-1,1].
% a,b: estremi dell'intervallo [a,b]
%
% Dati di uscita:
% i_err: numero reale non negativo che rappresenta una stima del massimo 
%        errore di interpolazione.


x=punti_chebyshev(n,a,b);
y=feval(f,x);
v=linspace(a,b,1000);
P = polyfit(x,y,n);
pv = polyval(P,v);
fv=feval(f,v);
i_err=norm(fv-pv,inf);